@@ -1,17 +1,10 @@
-/* ============================================================
- *
- * This file is a part of kdegraphics
- *
- * Date        : 2009-05-12
- * Description : Twain interface
- *
+/*
  * SPDX-FileCopyrightText: 2002-2003 Stephan Stapel <stephan dot stapel at web dot de>
  * SPDX-FileCopyrightText: 2008-2009 Gilles Caulier <caulier dot gilles at gmail dot com>
  * SPDX-FileCopyrightText: 2009, 2017 Kare Sars <kare dot sars at iki dot fi>
  *
  * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
- *
- * ============================================================ */
+ */
 
 #ifndef TWAINIFACE_H
 #define TWAINIFACE_H
@@ -25,7 +18,9 @@
 
 namespace KSaneIface
 {
-
+/**
+ * Twain interface
+ */
 class KSaneWidgetPrivate : public QWidget
 {
     Q_OBJECT
@@ -52,6 +47,7 @@ public Q_SLOTS:
 
 Q_SIGNALS:
     void ImageReady(QByteArray &data, int width, int height, int bytes_per_line, int format);
+    void qImageReady(const QImage &image);
 
 private:
 
