@@ -1,11 +1,10 @@
 /*
-Gwenview: an image viewer
-SPDX-FileCopyrightText: 2009 Aurélien Gâteau <agateau@kde.org>
-SPDX-FileCopyrightText: 2009 Kåre Sårs <kare.sars@iki.fi>
-SPDX-FileCopyrightText: 2014 Gregor Mitsch : port to KDE5 frameworks
-
-SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
-*/
+ * SPDX-FileCopyrightText: 2009 Aurélien Gâteau <agateau@kde.org>
+ * SPDX-FileCopyrightText: 2009 Kåre Sårs <kare.sars@iki.fi>
+ * SPDX-FileCopyrightText: 2014 Gregor Mitsch : port to KDE5 frameworks
+ *
+ * SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+ */
 
 #include "splittercollapser.h"
 
@@ -292,3 +291,5 @@ void SplitterCollapser::paintEvent(QPaintEvent *)
 }
 
 } // namespace
+
+#include "moc_splittercollapser.cpp"
